==> Tridium_EMEA_N4_Supervisor-4.10.11.12.zip: rc/RotationOrderEditor.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _get() { return _get = "undefined" != typeof Reflect && Reflect.get ? Reflect.get.bind() : function (e, t, r) { var p = _superPropBase(e, t); if (p) { var n = Object.getOwnPropertyDescriptor(p, t); return n.get ? n.get.call(arguments.length < 3 ? e : r) : n.value; } }, _get.apply(null, arguments); }
function _superPropBase(t, o) { for (; !{}.hasOwnProperty.call(t, o) && null !== (t = _getPrototypeOf(t));); return t; }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
/**
 * Copyright 2021 Tridium, Inc. All Rights Reserved.
 */

/** @jsx spandrel.jsx */

/**
 * API Status: **Private**
 * @module nmodule/vykonPro/rc/RotationOrderEditor
 */
define(['baja!', 'baja!gx:Font', 'bajaux/spandrel', 'bajaux/mixin/subscriberMixIn', 'bajaux/util/CommandButton', 'nmodule/webEditors/rc/wb/commands/ReorderSlotsCommand', 'css!nmodule/vykonPro/rc/vykonPro'], function (baja, types, spandrel, subscriberMixIn, CommandButton, ReorderSlotsCommand) {
  'use strict';

  var widgetDefaults = function widgetDefaults() {
    return {
      properties: {
        rootCssClass: 'ux-RotationOrderEditor',
        font: {
          value: baja.$('gx:Font', 'null').encodeToString(),
          typeSpec: 'gx:Font'
        }
      }
    };
  };
  return /*#__PURE__*/function (_spandrel) {
    function RotationOrderEditor(params) {
      var _this;
      _classCallCheck(this, RotationOrderEditor);
      _this = _callSuper(this, RotationOrderEditor, [{
        params: params,
        defaults: widgetDefaults()
      }]);
      subscriberMixIn(_this);
      _this.$subscriber = new baja.Subscriber();
      _this.$subscriber.attach('changed', function (prop) {
        if (prop.getName() === 'order') {
          _this.rerender();
        }
      });
      return _this;
    }
    _inherits(RotationOrderEditor, _spandrel);
    return _createClass(RotationOrderEditor, [{
      key: "doInitialize",
      value: function doInitialize(dom) {
        dom.closest('.ux-WebWidget').css('backgroundColor', 'transparent');
        return _get(_getPrototypeOf(RotationOrderEditor.prototype), "doInitialize", this).apply(this, arguments);
      }
    }]);
  }(spandrel(function (rotationOrder, _ref) {
    var properties = _ref.properties;
    var font = properties.font;
    var fontValue = baja.$('gx:Font').decodeFromString(font);
    var str = rotationOrder.get('order');
    var cmd = new ReorderSlotsCommand(rotationOrder);
    return cmd.loading().then(function () {
      cmd.setDisplayNameFormat('%lexicon(vykonPro:commands.reorder.label)%');
      cmd.setEnabled(true);
      return [spandrel.jsx("span", {
        $init: function $init(el) {
          return fontValue.applyToElement(el);
        },
        className: "ux-RotationOrderText"
      }, str), spandrel.jsx(CommandButton, {
        $init: function $init(el) {
          return fontValue.applyToElement(el);
        },
        className: "ux-RotationOrder",
        tagName: "span",
        value: cmd
      })];
    });
  }));
});

==> Tridium_EMEA_N4_Supervisor-4.14.3.24.zip: rc/RotationOrderEditor.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _classCallCheck(a, n) { if (!(a instanceof n)) throw new TypeError("Cannot call a class as a function"); }
function _defineProperties(e, r) { for (var t = 0; t < r.length; t++) { var o = r[t]; o.enumerable = o.enumerable || !1, o.configurable = !0, "value" in o && (o.writable = !0), Object.defineProperty(e, _toPropertyKey(o.key), o); } }
function _createClass(e, r, t) { return r && _defineProperties(e.prototype, r), t && _defineProperties(e, t), Object.defineProperty(e, "prototype", { writable: !1 }), e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(t, e) { if (e && ("object" == _typeof(e) || "function" == typeof e)) return e; if (void 0 !== e) throw new TypeError("Derived constructors may only return object or undefined"); return _assertThisInitialized(t); }
function _assertThisInitialized(e) { if (void 0 === e) throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); return e; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _superPropGet(t, e, r, o) { var p = _get(_getPrototypeOf(1 & o ? t.prototype : t), e, r); return 2 & o ? function (t) { return p.apply(r, t); } : p; }
function _get() { return _get = "undefined" != typeof Reflect && Reflect.get ? Reflect.get.bind() : function (e, t, r) { var p = _superPropBase(e, t); if (p) { var n = Object.getOwnPropertyDescriptor(p, t); return n.get ? n.get.call(arguments.length < 3 ? e : r) : n.value; } }, _get.apply(null, arguments); }
function _superPropBase(t, o) { for (; !{}.hasOwnProperty.call(t, o) && null !== (t = _getPrototypeOf(t));); return t; }
function _getPrototypeOf(t) { return _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function (t) { return t.__proto__ || Object.getPrototypeOf(t); }, _getPrototypeOf(t); }
function _inherits(t, e) { if ("function" != typeof e && null !== e) throw new TypeError("Super expression must either be null or a function"); t.prototype = Object.create(e && e.prototype, { constructor: { value: t, writable: !0, configurable: !0 } }), Object.defineProperty(t, "prototype", { writable: !1 }), e && _setPrototypeOf(t, e); }
function _setPrototypeOf(t, e) { return _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (t, e) { return t.__proto__ = e, t; }, _setPrototypeOf(t, e); }
/**
 * Copyright 2021 Tridium, Inc. All Rights Reserved.
 */

/** @jsx spandrel.jsx */

/**
 * API Status: **Private**
 * @module nmodule/vykonPro/rc/RotationOrderEditor
 */
define(['baja!', 'baja!gx:Font', 'bajaux/spandrel', 'bajaux/mixin/subscriberMixIn', 'bajaux/util/CommandButton', 'nmodule/webEditors/rc/wb/commands/ReorderSlotsCommand', 'css!nmodule/vykonPro/rc/vykonPro'], function (baja, types, spandrel, subscriberMixIn, CommandButton, ReorderSlotsCommand) {
  'use strict';

  var widgetDefaults = function widgetDefaults() {
    return {
      properties: {
        rootCssClass: 'ux-RotationOrderEditor',
        font: {
          value: baja.$('gx:Font', 'null').encodeToString(),
          typeSpec: 'gx:Font'
        }
      }
    };
  };
  return /*#__PURE__*/function (_spandrel) {
    function RotationOrderEditor(params) {
      var _this;
      _classCallCheck(this, RotationOrderEditor);
      _this = _callSuper(this, RotationOrderEditor, [{
        params: params,
        defaults: widgetDefaults()
      }]);
      subscriberMixIn(_this);
      _this.$subscriber = new baja.Subscriber();
      _this.$subscriber.attach('changed', function (prop) {
        if (prop.getName() === 'order') {
          _this.rerender();
        }
      });
      return _this;
    }
    _inherits(RotationOrderEditor, _spandrel);
    return _createClass(RotationOrderEditor, [{
      key: "doInitialize",
      value: function doInitialize(dom) {
        dom.closest('.ux-WebWidget').css('backgroundColor', 'transparent');
        return _superPropGet(RotationOrderEditor, "doInitialize", this, 3)(arguments);
      }
    }]);
  }(spandrel(function (rotationOrder, _ref) {
    var properties = _ref.properties;
    var font = properties.font;
    var fontValue = baja.$('gx:Font').decodeFromString(font);
    var str = rotationOrder.get('order');
    var cmd = new ReorderSlotsCommand(rotationOrder);
    return cmd.loading().then(function () {
      cmd.setDisplayNameFormat('%lexicon(vykonPro:commands.reorder.label)%');
      cmd.setEnabled(true);
      return [spandrel.jsx("span", {
        $init: function $init(el) {
          return fontValue.applyToElement(el);
        },
        className: "ux-RotationOrderText"
      }, str), spandrel.jsx(CommandButton, {
        $init: function $init(el) {
          return fontValue.applyToElement(el);
        },
        className: "ux-RotationOrder",
        tagName: "span",
        value: cmd
      })];
    });
  }));
});
